@@ -5,7 +5,7 @@ Support functions for contexts that are also needed by modules which the
 context_utils.py
 """
 
-import io
+import io, os
 
 from . import html_tools
 
@@ -216,6 +216,19 @@ class AllOnes(io.TextIOBase):
         return '1\n'
 
 
+def sandbox_filemap(spec):
+    """
+    Extracts the standard symlink mapping for sandbox files from the
+    given specification, based on its helper_files and starter_path
+    properties. The result maps absolute filenames to sandbox-relative
+    filenames and specifies how to copy helper files into a sandbox.
+    """
+    return {
+        os.path.abspath(os.path.join(spec.starter_path, helper)): helper
+        for helper in spec.helper_files
+    }
+
+
 #---------------------------#
 # ContextualValue machinery #
 #---------------------------#
