@@ -159,41 +159,36 @@ from potluck import meta # noqa E402
 
 meta.example("imperfect")
 
-meta.expect("partial", "style", "core", "documented")
-meta.expect("partial", "procedure", "extra", "ignore the results")
-meta.expect("partial", "procedure", "core", "define printMessage")
-meta.expect("accomplished", "procedure", "core", "define printMessage",
-            "call print")
-meta.expect("failed", "procedure", "core", "define printMessage",
-            "call indentMessage")
-# A few using IDs instead of rubric paths
+# using rubric paths
+meta.expect("partial", "documented")
+meta.expect("partial", "ignore the results")
+meta.expect("partial", "define printMessage")
+meta.expect("accomplished", "define printMessage", "call print")
+meta.expect("failed", "define printMessage", "call indentMessage")
+
+# A few using IDs instead of rubric paths (more dependable)
 meta.expect("partial", "#def-polygon$")
 meta.expect("partial", "#def-polygon:loop$")
 meta.expect("failed", "#def-polygon:loop:call-")
 
-# specifying as rubric paths:
-meta.expect("failed", "process", "core", "correct function calls")
-meta.expect("failed", "process", "core", "maintain invariants")
-meta.expect("failed", "process", "extra", "correct function calls")
-meta.expect("failed", "process", "extra", "maintain invariants")
-# Specifying the same goals using (automatically deduplicated)
-# identifiers:
-meta.expect("failed", "#core.test:polygon$")
-meta.expect("failed", "#core.test:polygon-2")
-meta.expect("failed", "#extra.test:polygon:advanced$")
-meta.expect("failed", "#extra.test:polygon:advanced-2")
+# these can't be specified as rubric paths any more because they're
+# ambiguous with the flattened rubrics
+meta.expect("failed", "#goal:core.test:polygon$")
+meta.expect("failed", "#goal:core.test:polygon-2")
+meta.expect("failed", "#goal:extra.test:polygon:advanced$")
+meta.expect("failed", "#goal:extra.test:polygon:advanced-2")
 
 # These two expectations are the same, using a goal rubric path and a
 # goal identifier
-meta.expect("failed", "product", "core", "ellipseArea")
+meta.expect("failed", "ellipseArea must")
 meta.expect("failed", "#core.test:ellipseArea$")
 # Note: "test:ellipseArea" would have been a sufficient ID here as well
 
-meta.expect("failed", "behavior", "core", "correct indentation")
-meta.expect("failed", "behavior", "extra", "correct output")
+meta.expect("failed", "correct indentation")
+meta.expect("accomplished", "#goal:core.test:printMessage$")
 
-meta.expect_validation("partial", "testing", "core", "defines required")
-meta.expect_validation("partial", "testing", "extra", "checks must succeed")
+meta.expect_validation("partial", "defines required")
+meta.expect_validation("partial", "checks must succeed")
 
 
 # Snippets for the instructions
